@@ -82,9 +82,9 @@ class Constants:
         -----
         The CSV file is expected to have the following structure;
         ```
-        column_name1,column_name2,column_name3 ...
-        row_name1,value2-1,value3-1 ...
-        row_name2,value2-2,value3-2 ...
+        col_name1,col_name2,col_name3 ...
+        row_name1,value_2-1,value_3-1 ...
+        row_name2,value_2-2,value_3-2 ...
         ```
         Note that column 1 is identical to the row labels.
 
